# -*- coding: utf-8 -*-

__license__ = "GNU General Public License (GPL) Version 3"
__author__ = 'Dan McDougall <YouKnowWho@YouKnowWhat.com>'

import os

#TODO:  Change make_backup and undo_from_backup to create/utilize binary diffs so we can undo multiple changes.
class ConfigFile(object):
    """Base class for all ConfigFile* objects containing many useful methods."""
    def __init__(self, filepath):
        """Sets up some basic stuff that all config files will need"""
        self.filepath = filepath

    def raw(self):
        """Returns the raw text in the config file"""
        return open(self.filepath, 'r').read()

# This method is a work-in-progress
    def make_init(self, script=None):
        """Generates and installs an init script that will undo changes in case of a power failure or crash.
        Plugin authors can optionally supply their own script (as a string)."""
        init_script_path = '/etc/init.d/S99_pyci_undo.sh'
        if script:
            init_script = open(init_script_path, 'w')
            init_script.write(script)
            init_script.close()
        else:
            script = "#!/bin/sh\n"
            script += "mv %s.pycibak %s" % (self.filepath, self.filepath)
            init_script = open(init_script_path, 'w')
            init_script.write(script)
            init_script.close()

    def make_backup(self, filepath):
        """Makes a backup file in case we need to undo"""
        os.system("cp %s %s.pycibak" % (filepath, filepath))

    def undo_from_backup(self, filepath):
        """Undoes any changes to 'filepath' by moving the backup back to the original location"""
        os.system("[ -f %s.pycibak ] && mv %s.pycibak %s" % (filepath, filepath, filepath))

    def save(self):
        """Your ConfigFile object will need to override this in it's own save method"""
        raise NotImplementedError

    def save_raw(self, text):
        """Saves the raw (plaintext) version of the config file using 'text'"""
        self.make_backup(self.filepath)
        f = open(self.filepath, 'w')
        f.write(text)
        f.close()
        self.made_changes()

    def save_delimited(self, fields_list, filepath, delimiter):
        """Saves 'fields_list' (list of lists or tuples) as a delimited file using the given delimiter.

        For example, to save /etc/passwd using this method you could:
            self.save_delimited(passwd_list, '/etc/passwd', ':')"""
        out_string = ""
        f = open(filepath, 'w')
        for line in fields_list:
            line = ":".join(line) + '\n'
            out_string += line
        f.write(out_string)
        f.close()

    def made_changes(self):
        """Writes a '1' to '/tmp/pyci_changes' to indicate that changes have been made that require a reboot"""
        f = open('/tmp/pyci_changes', 'w')
        f.write('1')
        f.close()

    def cleanup(self, filepath):
        """Deletes any leftover backup files and removes the emergency init script"""
        os.system("[ -f %s.pycibak ] && rm -f %s.pycibak" % (filepath, filepath))

# This method is a work-in-progress
    def apply_changes(self, undo):
        template = lookup_template("html", "apply_changes.mako")
        return template.render(plugin_object=Plugin)

# This method is a work-in-progress
    def undo_changes(self, undo):
        template = lookup_template("html", "undo_changes.mako")
        return template.render(plugin_object=Plugin)