#!/usr/bin/env python
# -*- coding: utf-8 -*-

__license__ = "GNU General Public License (GPL) Version 3"
__author__ = 'Dan McDougall <YouKnowWho@YouKnowWhat.com>'

import os, sys
from time import sleep
import speedtester
from PyQt4 import QtGui, QtCore
from speed_test_ui import Ui_MainWindow

class SpeedTestGUI(QtGui.QMainWindow):
    def __init__(self):
        QtGui.QMainWindow.__init__(self)

        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)
        self.setWindowTitle('PyCI Speed Test Client')
        self.statusBar = self.statusBar()
        self._menuBar()
        self.msg('Please enter the hostname/IP address of the Speed Test Server')
        self.speed_test_thread = None

        self.connect(self, QtCore.SIGNAL("msg"), self.msg)
        self.connect(self, QtCore.SIGNAL("set_lcd"), self.set_lcd)
        self.createActions()


    def _menuBar(self):
        """Sets up the menus"""
        exit = QtGui.QAction(QtGui.QIcon('icons/application-exit.png'), 'Exit', self)
        exit.setShortcut('Ctrl+Q')
        exit.setStatusTip('Exit application')
        self.connect(exit, QtCore.SIGNAL('triggered()'), QtCore.SLOT('close()'))

        menubar = self.menuBar()
        filemenu = menubar.addMenu('&File')
        filemenu.addAction(exit)

    def createActions(self):
        """Connects our QtCore.SIGNALs to various actions in the GUI"""

        self.connect(self.ui.host, QtCore.SIGNAL("returnPressed()"), self.start_speed_test)
        self.connect(self.ui.startButton, QtCore.SIGNAL("clicked()"), self.start_speed_test)
        self.connect(self.ui.stopButton, QtCore.SIGNAL("clicked()"), self.stop_speed_test)

        self.quitAction = QtGui.QAction(self.tr("&Quit"), self)
        self.connect(self.quitAction, QtCore.SIGNAL("triggered()"), QtGui.qApp, QtCore.SLOT("quit()"))

    def msg(self, msg):
        """Show a message, 'msg' in the statusBar"""
        self.statusBar.showMessage(msg)

    def set_lcd(self, value):
        """Set the LCD to 'value' which must be a float()"""
        self.ui.lcdNumber.display(value)

    def start_speed_test(self):
        """Connects to the Speed Test Server and initiates the speed test.
        Grabs the hostname/IP from self.ui.host"""
        self.host = str(self.ui.host.text())
        if len(self.host):
            # TODO: Add input validation here
            self.msg("Connecting to '%s'" % self.host)
            self.speed_test_thread = speedtester.SpeedTestClient(host=self.host)
            self.speed_test_thread.setName('SpeedTestClient')
            self.speed_test_thread.start()
            self.status_thread = SpeedUpdateThread(self.speed_test_thread)
            self.connect(self.status_thread, QtCore.SIGNAL("msg"), self.msg)
            self.connect(self.status_thread, QtCore.SIGNAL("set_lcd"), self.set_lcd)
            self.status_thread.start()

    def stop_speed_test(self):
        """Connects to the Speed Test Server and starts up the speed test."""
        self.msg("Stopping speed test...")
        speedtester.stop_speedtest_client()
        self.status_thread.quit()

class SpeedUpdateThread(QtCore.QThread):
    def __init__(self, speed_test_thread, parent=None):
        QtCore.QThread.__init__(self, parent)
        self.speed_test_thread = speed_test_thread
        self.exiting = False

    def quit(self):
        self.exiting = True

    def run(self):
        while not self.exiting:
            if self.speed_test_thread:
                speed = self.speed_test_thread.speed
                if speed:
                    self.emit(QtCore.SIGNAL('msg'), "Speed test is running")
                self.emit(QtCore.SIGNAL('set_lcd'), float(speed))
            sleep(1)
        self.exiting = True
        self.closed = True
        self.emit(QtCore.SIGNAL('msg'), "Disconnected from Speed Test Server")

    def __del__(self):
        self.exiting = True
        self.wait()

if __name__ == "__main__":
    app = QtGui.QApplication(sys.argv)
    window = SpeedTestGUI()
    window.show()
    sys.exit(app.exec_())