# -*- coding: utf-8 -*-

__license__ = "GNU General Public License (GPL) Version 3"
__author__ = 'Dan McDougall <YouKnowWho@YouKnowWhat.com>'

from commands import getoutput

class brctl(object):
    """
    A class to get and set bridge settings via the brctl utility.
    """
    def __init__(self):
        self.bridges = {}
        self.get_bridges()

    def get_bridges(self):
        """Populates self.bridges with the output of 'brctl show'"""
        output = getoutput('brctl show')
        if len(output.split('\n')) == 1:
            pass # No bridges
        else:
            bridge_name = None
            for index, line in enumerate(output.split('\n')):
                if index == 0:
                    pass # First line is just the header
                else:
                    # The brctl command output is tab-separated columns
                    fields = [a for a in line.rstrip('\n').split('\t') if a] # Remove empty fields

                    # If we already set a bridge_name then we just want to append the interface
                    if bridge_name and len(fields) == 1: # This line just contains an interface
                        # Append it to our list of interfaces belonging to this bridge
                        if_list.append(fields[0])
                    if len(fields) == 4: # Starting a new bridge section
                        if_list = [] # Make a new interface list
                        bridge_dict = {} # ...and a new dict for these values
                        bridge_name = fields[0]
                        bridge_id = fields[1]
                        stp_enabled = fields[2]
                        if_list.append(fields[3]) # Our first interface
                        bridge_dict.update({
                            'bridge_id': bridge_id,
                            'stp_enabled': stp_enabled,
                            'if_list': if_list, # Good thing lists are always in-place!
                        })
                        self.bridges.update({bridge_name: bridge_dict})

    def __repr__(self):
        return str(self.bridges)

    def __str__(self):
        return getoutput('brctl show') # Cheating, I know!
