# -*- coding: utf-8 -*-

__license__ = "GNU General Public License (GPL) Version 3"
__author__ = 'Dan McDougall <YouKnowWho@YouKnowWhat.com>'

from plugin_utils import get_translation
from odict import odict

# Internationalization
trans = get_translation(__file__)
_ = lambda s: trans.ugettext(s)

interface_options = odict([
    ('apn', {'help': _('The Access Point Name (for cellular 3G connections).')}),
    ('bcast', {'help': _('The IPv4 broadcast address (e.g. 192.168.1.255)')}),
    ('connect', {'help': _('The connect script to use with 3G, ppp, pptp, pppoa, and pppoe connections.')}),
    ('defaultroute', {'help': _('For use with the 3G, ppp, pptp, pppoa, and pppoe protocols: The default route this interface should use to access external networks (such as the Internet.  Not to be confused with the "gateway" option.')}),
    ('demand', {'help': _('Dial-on-demand timeout: The number of seconds to wait before closing the connection due to inactivity.  Only used with the 3G, ppp, pptp, (pppoa, and pppoe protocols.')}),
    ('device', {'help': _('The modem device to use with this connection. Only used with 3G and PPP protocols.')}),
    ('disconnect', {'help': _('The disconnect script to use with 3G, ppp, pptp, pppoa, and pppoe connections.')}),
    ('dns', {
        'help': _("The IP address of your local DNS server.  Typically provided by your Internet service provider.  You can have multiple dns options."),
    }),
    ('encaps', {'help': _('The PPPoA encapsulation mode to use with this interface.')}),
    ('gateway', {
        'help': _('The IPv4 address of the router you wish to use to access hosts outside of your local subnet.  Gateways are usually the first address in a given subnet (e.g. 192.168.1.1 or 10.0.0.1)')
    }),
    ('ifname', {
        'help': _("<p>The actual name of the interface in question (e.g. eth0).  This is the name you'd see when using the 'ifconfig' command.</p> <p><strong>To enable VLAN tagging</strong> just name the interface like so: 'eth0.7'.  Where 'eth0' is the name of the interface and 7 is the VLAN you want it to be on.</p><p><strong>Note on bridging:</strong> If this interface is a bridge you may specify multiple interfaces separated by spaces.</p>")
    }),
    ('interface', {'help': _('The parent interface of this alias. (mandatory)')}),
    ('ip6addr', {'help': _('IPv6 address to assign to this interface.')}),
    ('ip6gw', {'help': _('The address of your default IPv6 gateway.')}),
    ('ipaddr', {'help': _('The IP address to assign this interface  (e.g. 192.168.1.1)')}),
    ('ipv6', {'help': _('PPP only:  Enable IPv6 over the PPP link.')}),
    ('keepalive', {'help': _('The number of connection failures before the connection is reestablished.')}),
    ('macaddr', {'help': _('The MAC address to assign this interface (overrides the hardware MAC).')}),
    ('maxwait', {'help': _('The number of seconds to wait for the device to become ready before giving up.  Only used with the 3G protocol.')}),
    ('mtu', {'help': _('The maximum transmission unit (MTU) size for this interface.  Defaults to 1500 if not set.')}),
    ('netmask', {
        'help': _('A 32-bit number representing the scope of the local subnet.  e.g 255.255.255.0')
    }),
    ('password', {'help': _('The password to use with 3G, ppp, pptp, pppoa, and pppoe connections.')}),
    ('peerdns', {'help': _('Enable the use of peer DNS with 3G, ppp, pptp, pppoa, and pppoe connections.')}),
    ('pincode', {'help': _('The PIN to gain access to cellular (3G) modems.')}),
    ('pppd_options', {'help': _('Additional options to be passed to the pppd daemon when establishing a 3G, ppp, pptp, pppoa, and pppoe connection.')}),
    ('proto', {'help': _("The protocol to use for this interface.")}),
    ('server', {'help': _('With PPTP connections, the Point-to-Point Tunneling Protocol (PPTP) server to use.')}),
    ('service', {'help': _('The type of service being used with cellular (3G) connections.')}),
    ('stp', {'help': _('Turn Spanning Tree Protocol (STP) on or off for this bridge.')}),
    ('type', {'help': _('The type of this interface: Only valid option is "bridge".')}),
    ('username', {'help': _('The username to use with 3G, ppp, pptp, pppoa, and pppoe connections.')}),
    ('vci', {'help': _('PPPoA Vertical Channel Identifier (VCI) setting.  This is typically provided by your ISP.')}),
    ('vpi', {'help': _('PPPoA Vertical Path Identifier (VPI) setting.  This is typically provided by your ISP.')}),
])
wifi_device_options = odict([
    ('apn', {'help': _('The Access Point Name (for cellular 3G connections).')}),
    ('type', {'help': _('The type of wireless device.  e.g. "broadcom", "aetheros", "madwifi", "mac80211", etc.')}),
    ('channel', {'help': _('The wireless channel you wish this device to operate on.  Must be an integer between 1 and 14.')}),
    ('country', {'help': _('The two-letter country code to use when initializing the firmware of this device (only Broadcom devices need this).')}),
    ('disabled', {'help': _('"1" or "0" indicating whether or not this device should be enabled.')}),
    ('distance', {'help': _("Distance to farthest network member in meters.  It is used by the wireless device's firmware to optimize performance.  Only used with device types of 'aetheros' and 'broadcom'")}),
    ('diversity', {'help': _('"1" or "0":  If enabled this will allow the use of multiple antennas to compensate for multipath interference.')}),
    ('frameburst', {'help': _('"1" or "0": A Broadcom-only option (aka "Super Feature") that enables bursting of network frames to improve performance.  Doesn\'t usually work very well and can cause problems for some client devices.')}),
    ('hwmode', {'help': _('This sets the operating mode of Aetheros devices.  Must be one of, "11b" (802.11b), "11a" "fh" (frequency hopping), "11g", "11gdt", "11adt", "11bg".')}),
    ('macfilter', {'help': _('"allow" or "deny":  This is a Broadcom-only feature that tells the firmware how to use the maclist...  If set to "allow" it will only allow connections from MAC addresses in the maclist.  If set to "deny" it will deny connections from those MAC addresses in the maclist.')}),
    ('maclist', {'help': _('This option should contain a space-separated list of MAC address you wish to either allow or block depending on your macfilter setting.  This is a Broadcom-only option.<br />Example: 00:12:17:94:04:10 00:18:F8:2C:9A:FA')}),
    ('maxassoc', {'help': _('The maximum number of allowed connections to this wireless device.  Broadcom-only.')}),
    ('rxantenna', {'help': _('Receiver Antenna (integer)')}),
    ('txantenna', {'help': _('Transmitter Antenna (integer)')}),
    ('txpower', {'help': _('The transmit power (in dbm) of the wireless device.  Higher values will provide greater range while lower values will decrease interference.')}),
])